==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebPivotValueEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotValueDetailDescriptionMetadata } from "./WebPivotValueDetailDescriptionMetadata";
import { WebPivotValueEventArgsDescription } from "./WebPivotValueEventArgsDescription";
/**
 * @hidden
 */
export let WebPivotValueEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPivotValueEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPivotValueEventArgsDescriptionMetadata.a == null) {
                WebPivotValueEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPivotValueEventArgsDescriptionMetadata.c(WebPivotValueEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPivotValueEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPivotValueEventArgsDescriptionMetadata.a);
            WebPivotValueDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PivotValueEventArgs");
            a.item("Detail", "ExportedType:WebPivotValueDetail");
        }
        static d(a) {
            WebPivotValueEventArgsDescriptionMetadata.b(a);
            a.ad("WebPivotValueEventArgs", () => new WebPivotValueEventArgsDescription());
            a.ac("WebPivotValueEventArgs", WebPivotValueEventArgsDescriptionMetadata.a);
        }
    }
    WebPivotValueEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPivotValueEventArgsDescriptionMetadata, 'WebPivotValueEventArgsDescriptionMetadata');
    WebPivotValueEventArgsDescriptionMetadata.a = null;
    return WebPivotValueEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebPivotValueEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotValueDetailDescriptionMetadata } from "./WebPivotValueDetailDescriptionMetadata";
import { WebPivotValueEventArgsDescription } from "./WebPivotValueEventArgsDescription";
/**
 * @hidden
 */
export let WebPivotValueEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPivotValueEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPivotValueEventArgsDescriptionMetadata.a == null) {
                WebPivotValueEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPivotValueEventArgsDescriptionMetadata.c(WebPivotValueEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPivotValueEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPivotValueEventArgsDescriptionMetadata.a);
            WebPivotValueDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PivotValueEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "ExportedType:WebPivotValueDetail");
        }
        static d(a) {
            WebPivotValueEventArgsDescriptionMetadata.b(a);
            a.ae("WebPivotValueEventArgs", () => new WebPivotValueEventArgsDescription());
            a.ad("WebPivotValueEventArgs", WebPivotValueEventArgsDescriptionMetadata.a);
        }
    }
    WebPivotValueEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPivotValueEventArgsDescriptionMetadata, 'WebPivotValueEventArgsDescriptionMetadata');
    WebPivotValueEventArgsDescriptionMetadata.a = null;
    return WebPivotValueEventArgsDescriptionMetadata;
})();
